module DawandaConverter
  class Money
    @@conversions =  Hash.new #Declared as a Class variable so all objects (Money) created have the same conversion rates available

    def initialize(amount, currency)
        @amount = ( amount || 0 ) #if nil it just assigns ZERO
        @currency = currency
    end
    #--------------------ACCESSORS---------------------------------------------#
    def amount
        @amount
    end

    def currency
        @currency
    end

    def currency=(currency)
        @currency = currency
    end

    def amount=(amount)
        @amount = (amount || 0 )
    end

    def inspect
       "#{@amount} #{@currency}"
    end

    def conversions
      @@conversions
    end
    #--------------------------------------------------------------------------#

    def self.conversion_rates(currency="", hash={})
        @@conversions[currency] = hash unless currency.empty? || hash.empty?
    end

    def convert_to(currency)
       unless @@conversions.empty? || @@conversions[self.currency].nil?
         self.amount = @@conversions[self.currency][currency].to_f * self.amount
         self.currency = currency
       else
         puts "You must initialize conversion rates first."
       end
    end

    #-------------OPERATORS SECTION-------------------------------------------#

    def +(y)
      if self.currency != y.currency
         y.convert_to(self.currency)
      end

      return "#{self.amount + y.amount} #{self.currency}"
    end

    def -(y)
      if self.currency != y.currency
         y.convert_to(self.currency)
      end

      return "#{self.amount - y.amount} #{self.currency}"
    end

    def /(y)
      return "You cannot devide by ZERO!." if y == 0
      return "#{self.amount / y} #{self.currency}"
    end

    def *(y)
      return "#{self.amount * y} #{self.currency}"
    end

    def ==(y)
      return true if self.amount == y.amount && self.currency == y.currency
      return false
    end

    def <(y)
      if self.currency != y.currency
         y.convert_to(self.currency)
      end
      return true if self.amount < y.amount

      return false
    end

    def >(y)
      if self.currency != y.currency
         y.convert_to(self.currency)
      end
      return true if self.amount > y.amount

      return false
    end

  end
end
